==> veracity-source-1.0.0.10517.tar.gz: veracity/src/tortoise/VeracityShellExtension/OverlayHandlers/VeracityOverlay_Base.cpp <==
#include "VeracityOverlay_Base.h"
#include "../VeracityCacheMessaging.h"
#include "../GlobalHelpers.h"

extern "C"{
#define BEGIN_EXTERN_C
#define END_EXTERN_C
#include "sg.h"
#include "sg_workingdir_prototypes.h"

}

VeracityOverlay_Base::VeracityOverlay_Base(void)
{
}


VeracityOverlay_Base::~VeracityOverlay_Base(void)
{
}
bool VeracityOverlay_Base::IsVeracityPrivateDir(SG_context* pCtx, SG_pathname * pPathName)
{
	bool returnVal = false;
	SG_bool bMatches = SG_FALSE;
	SG_file_spec * pFileSpec = NULL;

	SG_ERR_CHECK( SG_FILE_SPEC__ALLOC(pCtx, &pFileSpec)  );
	SG_uint32 uFlags = SG_FILE_SPEC__MATCH_TRAILING_SLASH | SG_FILE_SPEC__MATCH_FOLDERS_RECURSIVELY | SG_FILE_SPEC__MATCH_ANYWHERE;

	// TODO 2011/04/14 How does adding an ignored ".sgdrawer" compare with __load_reserved() which does that?
	// TODO            See W7301.

	SG_ERR_CHECK(  SG_file_spec__add_pattern__sz(pCtx, pFileSpec, SG_FILE_SPEC__PATTERN__IGNORE, ".sgdrawer", uFlags)  );
	SG_ERR_CHECK(  SG_file_spec__match_path(pCtx, pFileSpec, SG_pathname__sz(pPathName), SG_FILE_SPEC__MATCH_ANYWHERE, &bMatches)  );

	if (bMatches == SG_FALSE)
	{
		returnVal = true;
	}

	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return returnVal;
fail:
	NotifyError(pCtx);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return false;
}
bool VeracityOverlay_Base::IsIgnored(SG_context* pCtx, SG_pathname * pPathName)
{
	bool returnVal = false;
	SG_bool bMatches = SG_FALSE;
	SG_repo * pRepo = NULL;
	SG_file_spec * pFileSpec = NULL;
	SG_string * pstrRepoDescriptorName = NULL;
	SG_pathname * pPathWorkingDirTop = NULL;

	SG_ERR_CHECK(  SG_workingdir__find_mapping(pCtx, pPathName, &pPathWorkingDirTop, &pstrRepoDescriptorName, NULL)  );
	SG_REPO__OPEN_REPO_INSTANCE(pCtx, SG_string__sz(pstrRepoDescriptorName), &pRepo);
	if (SG_context__err_equals(pCtx, SG_ERR_NOT_A_WORKING_COPY) || SG_context__err_equals(pCtx, SG_ERR_NOTAREPOSITORY))
	{
		SG_context__err_reset(pCtx);
		goto cleanup;
	}
	else
	{
		SG_ERR_CHECK_CURRENT;
	}

	SG_ERR_CHECK( SG_FILE_SPEC__ALLOC(pCtx, &pFileSpec)  );
	SG_uint32 uFlags = SG_FILE_SPEC__MATCH_TRAILING_SLASH | SG_FILE_SPEC__MATCH_FOLDERS_RECURSIVELY | SG_FILE_SPEC__MATCH_ANYWHERE;
	SG_ERR_CHECK(  SG_file_spec__load_ignores(pCtx, pFileSpec, pRepo, pPathWorkingDirTop, uFlags)  );

	// TODO 2011/07/17 Again this reference to .sgdrawer should be a __load_reserved().
	// TODO            See W7301.

	SG_ERR_CHECK(  SG_file_spec__add_pattern__sz(pCtx, pFileSpec, SG_FILE_SPEC__PATTERN__IGNORE, ".sgdrawer", uFlags)  );
	SG_ERR_CHECK(  SG_file_spec__match_path(pCtx, pFileSpec, SG_pathname__sz(pPathName), SG_FILE_SPEC__MATCH_ANYWHERE, &bMatches)  );

	if (bMatches == SG_FALSE)
	{
		returnVal = true;
	}

	SG_PATHNAME_NULLFREE(pCtx, pPathWorkingDirTop);
	SG_REPO_NULLFREE(pCtx, pRepo);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return returnVal;
fail:
	NotifyError(pCtx);
cleanup:
	SG_PATHNAME_NULLFREE(pCtx, pPathWorkingDirTop);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	SG_REPO_NULLFREE(pCtx, pRepo);
	return false;
}
bool VeracityOverlay_Base::StatusHas(SG_diffstatus_flags testMe, SG_diffstatus_flags lookForMe)
{
	return (testMe & lookForMe) == lookForMe;
}

SG_diffstatus_flags VeracityOverlay_Base::GetStatus(SG_context* pCtx, const char * psz_Path)
{	
	
	SG_diffstatus_flags statusFlags = SG_DIFFSTATUS_FLAGS__ZERO;
	SG_ERR_CHECK(  statusFlags = GlobalHelpers::GetStatus(pCtx, psz_Path)  );
fail:
	return statusFlags;
	
}

bool VeracityOverlay_Base::IsConflict(SG_context* pCtx, SG_pathname * pPathName)
{
	bool isConflict = false;
	SG_ERR_CHECK(  isConflict = GlobalHelpers::IsConflict(pCtx, SG_pathname__sz(pPathName))  );
fail:
	return isConflict;
}

bool VeracityOverlay_Base::InAWorkingFolder(SG_context* pCtx, LPCWSTR pwszPath, SG_pathname ** ppPathName)
{
	SG_pathname * pPathCwd = NULL;
	SG_string * pstr_selectedFile = NULL;
	SG_ERR_CHECK(  SG_STRING__ALLOC(pCtx, &pstr_selectedFile)  );
	
	SG_ERR_CHECK(  SG_UTF8__INTERN_FROM_OS_BUFFER(pCtx, pstr_selectedFile, pwszPath)  );
	
	SG_ERR_CHECK(  SG_PATHNAME__ALLOC__SZ(pCtx, &pPathCwd, SG_string__sz(pstr_selectedFile))  );
	
	SG_string * pstrRepoDescriptorName = NULL;
	SG_workingdir__find_mapping(pCtx, pPathCwd, NULL, &pstrRepoDescriptorName, NULL);
	
	if (SG_context__err_equals(pCtx, SG_ERR_NOT_A_WORKING_COPY) || SG_context__err_equals(pCtx, SG_ERR_NOTAREPOSITORY))
	{
		SG_context__err_reset(pCtx);
		goto cleanup;
	}
	else
	{
		SG_ERR_CHECK_CURRENT;
	}
	*ppPathName = pPathCwd;
	pPathCwd = NULL;
	//SG_RETURN_AND_NULL(pPathCwd, ppPathName);
	SG_STRING_NULLFREE(pCtx, pstr_selectedFile);
	return true;;
fail:
	NotifyError(pCtx);
cleanup:
	SG_PATHNAME_NULLFREE(pCtx, pPathCwd);
	SG_STRING_NULLFREE(pCtx, pstr_selectedFile);
	return false;
}

SG_context * VeracityOverlay_Base::GetAContext()
{
	SG_context* pCtx = NULL;
	SG_error err;
	err = SG_context__alloc(&pCtx);
	return pCtx;
}

void VeracityOverlay_Base::NotifyError(SG_context * pCtx)
{
	SG_UNUSED_PARAM(pCtx);

	
#if  DEBUG
	wchar_t * pBuf = NULL;
	SG_string * errorMessage = NULL;
	SG_context * pSubContext = NULL;
	SG_context__alloc(&pSubContext);
	SG_context__err_to_string(pCtx, &errorMessage);
	SG_utf8__extern_to_os_buffer__wchar(pSubContext, SG_string__sz(errorMessage), &pBuf, NULL);
	MessageBox(NULL,(const TCHAR *)pBuf,NULL,MB_OK|MB_ICONERROR);
	SG_CONTEXT_NULLFREE(pSubContext);
	free(pBuf);
#else
	SG_log__report_error__current_error(pCtx);
#endif
}

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/tortoise/VeracityShellExtension/OverlayHandlers/VeracityOverlay_Base.cpp <==
#include "VeracityOverlay_Base.h"
#include "../VeracityCacheMessaging.h"
#include "../GlobalHelpers.h"

extern "C"{
#define BEGIN_EXTERN_C
#define END_EXTERN_C
#include "sg.h"
#include "sg_workingdir_prototypes.h"

}

VeracityOverlay_Base::VeracityOverlay_Base(void)
{
}


VeracityOverlay_Base::~VeracityOverlay_Base(void)
{
}
bool VeracityOverlay_Base::IsVeracityPrivateDir(SG_context* pCtx, SG_pathname * pPathName)
{
	bool returnVal = false;
	SG_bool bMatches = SG_FALSE;
	SG_file_spec * pFileSpec = NULL;

	SG_ERR_CHECK( SG_FILE_SPEC__ALLOC(pCtx, &pFileSpec)  );
	SG_uint32 uFlags = SG_FILE_SPEC__MATCH_TRAILING_SLASH | SG_FILE_SPEC__MATCH_FOLDERS_RECURSIVELY | SG_FILE_SPEC__MATCH_ANYWHERE;

	// TODO 2011/04/14 How does adding an ignored ".sgdrawer" compare with __load_reserved() which does that?
	// TODO            See W7301.

	SG_ERR_CHECK(  SG_file_spec__add_pattern__sz(pCtx, pFileSpec, SG_FILE_SPEC__PATTERN__IGNORE, ".sgdrawer", uFlags)  );
	SG_ERR_CHECK(  SG_file_spec__match_path(pCtx, pFileSpec, SG_pathname__sz(pPathName), SG_FILE_SPEC__MATCH_ANYWHERE, &bMatches)  );

	if (bMatches == SG_FALSE)
	{
		returnVal = true;
	}

	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return returnVal;
fail:
	NotifyError(pCtx);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return false;
}
bool VeracityOverlay_Base::IsIgnored(SG_context* pCtx, SG_pathname * pPathName)
{
	bool returnVal = false;
	SG_bool bMatches = SG_FALSE;
	SG_repo * pRepo = NULL;
	SG_file_spec * pFileSpec = NULL;
	SG_string * pstrRepoDescriptorName = NULL;
	SG_pathname * pPathWorkingDirTop = NULL;

	SG_ERR_CHECK(  SG_workingdir__find_mapping(pCtx, pPathName, &pPathWorkingDirTop, &pstrRepoDescriptorName, NULL)  );
	SG_REPO__OPEN_REPO_INSTANCE(pCtx, SG_string__sz(pstrRepoDescriptorName), &pRepo);
	if (SG_context__err_equals(pCtx, SG_ERR_NOT_A_WORKING_COPY) || SG_context__err_equals(pCtx, SG_ERR_NOTAREPOSITORY))
	{
		SG_context__err_reset(pCtx);
		goto cleanup;
	}
	else
	{
		SG_ERR_CHECK_CURRENT;
	}

	SG_ERR_CHECK( SG_FILE_SPEC__ALLOC(pCtx, &pFileSpec)  );
	SG_uint32 uFlags = SG_FILE_SPEC__MATCH_TRAILING_SLASH | SG_FILE_SPEC__MATCH_FOLDERS_RECURSIVELY | SG_FILE_SPEC__MATCH_ANYWHERE;
	SG_ERR_CHECK(  SG_file_spec__load_ignores(pCtx, pFileSpec, pRepo, pPathWorkingDirTop, uFlags)  );

	// TODO 2011/07/17 Again this reference to .sgdrawer should be a __load_reserved().
	// TODO            See W7301.

	SG_ERR_CHECK(  SG_file_spec__add_pattern__sz(pCtx, pFileSpec, SG_FILE_SPEC__PATTERN__IGNORE, ".sgdrawer", uFlags)  );
	SG_ERR_CHECK(  SG_file_spec__match_path(pCtx, pFileSpec, SG_pathname__sz(pPathName), SG_FILE_SPEC__MATCH_ANYWHERE, &bMatches)  );

	if (bMatches == SG_FALSE)
	{
		returnVal = true;
	}

	SG_PATHNAME_NULLFREE(pCtx, pPathWorkingDirTop);
	SG_REPO_NULLFREE(pCtx, pRepo);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	return returnVal;
fail:
	NotifyError(pCtx);
cleanup:
	SG_PATHNAME_NULLFREE(pCtx, pPathWorkingDirTop);
	SG_FILE_SPEC_NULLFREE(pCtx, pFileSpec);
	SG_REPO_NULLFREE(pCtx, pRepo);
	return false;
}
bool VeracityOverlay_Base::StatusHas(SG_diffstatus_flags testMe, SG_diffstatus_flags lookForMe)
{
	return (testMe & lookForMe) == lookForMe;
}

SG_diffstatus_flags VeracityOverlay_Base::GetStatus(SG_context* pCtx, const char * psz_Path)
{	
	
	SG_diffstatus_flags statusFlags = SG_DIFFSTATUS_FLAGS__ZERO;
	SG_ERR_CHECK(  statusFlags = GlobalHelpers::GetStatus(pCtx, psz_Path)  );
fail:
	return statusFlags;
	
}

bool VeracityOverlay_Base::IsConflict(SG_context* pCtx, SG_pathname * pPathName)
{
	bool isConflict = false;
	SG_ERR_CHECK(  isConflict = GlobalHelpers::IsConflict(pCtx, SG_pathname__sz(pPathName))  );
fail:
	return isConflict;
}

bool VeracityOverlay_Base::InAWorkingFolder(SG_context* pCtx, LPCWSTR pwszPath, SG_pathname ** ppPathName)
{
	SG_pathname * pPathCwd = NULL;
	SG_string * pstr_selectedFile = NULL;
	SG_ERR_CHECK(  SG_STRING__ALLOC(pCtx, &pstr_selectedFile)  );
	
	SG_ERR_CHECK(  SG_UTF8__INTERN_FROM_OS_BUFFER(pCtx, pstr_selectedFile, pwszPath)  );
	
	SG_ERR_CHECK(  SG_PATHNAME__ALLOC__SZ(pCtx, &pPathCwd, SG_string__sz(pstr_selectedFile))  );
	
	SG_string * pstrRepoDescriptorName = NULL;
	SG_workingdir__find_mapping(pCtx, pPathCwd, NULL, &pstrRepoDescriptorName, NULL);
	
	if (SG_context__err_equals(pCtx, SG_ERR_NOT_A_WORKING_COPY) || SG_context__err_equals(pCtx, SG_ERR_NOTAREPOSITORY))
	{
		SG_context__err_reset(pCtx);
		goto cleanup;
	}
	else
	{
		SG_ERR_CHECK_CURRENT;
	}
	*ppPathName = pPathCwd;
	pPathCwd = NULL;
	//SG_RETURN_AND_NULL(pPathCwd, ppPathName);
	SG_STRING_NULLFREE(pCtx, pstr_selectedFile);
	return true;;
fail:
	NotifyError(pCtx);
cleanup:
	SG_PATHNAME_NULLFREE(pCtx, pPathCwd);
	SG_STRING_NULLFREE(pCtx, pstr_selectedFile);
	return false;
}

SG_context * VeracityOverlay_Base::GetAContext()
{
	SG_context* pCtx = NULL;
	SG_error err;
	err = SG_context__alloc(&pCtx);
	return pCtx;
}

void VeracityOverlay_Base::NotifyError(SG_context * pCtx)
{
	SG_UNUSED_PARAM(pCtx);

	
#if  DEBUG
	wchar_t * pBuf = NULL;
	SG_string * errorMessage = NULL;
	SG_context * pSubContext = NULL;
	SG_context__alloc(&pSubContext);
	SG_context__err_to_string(pCtx, SG_TRUE, &errorMessage);
	SG_utf8__extern_to_os_buffer__wchar(pSubContext, SG_string__sz(errorMessage), &pBuf, NULL);
	MessageBox(NULL,(const TCHAR *)pBuf,NULL,MB_OK|MB_ICONERROR);
	SG_CONTEXT_NULLFREE(pSubContext);
	free(pBuf);
#else
	SG_log__report_error__current_error(pCtx);
#endif
}
